# Tahrir

Tahrir is a [Flask](https://flask.palletsprojects.com/) application used by the Fedora Project for
issuing [Open Badges](https://openbadges.org). As per the [about](https://openbadges.org/about/) page:

> The concept of Open Badges originated among those working at the Mozilla and
> MacArthur foundations, and out of the research of Erin Knight, founding
> director of the Open Badges project at Mozilla.

Originally, information was hosted on the [Mozilla Wiki][moz-badges].

[moz-badges]: https://wiki.mozilla.org/index.php?title=Badges&oldid=1170927

Tahrir is [Arabic for Liberation](http://en.wikipedia.org/wiki/Tahrir_Square).
The name is total overkill.

The project is hosted [on Github](https://github.com/fedora-infra/tahrir).
You can read [the documentation](https://tahrir.readthedocs.org/) for more details.

You can see Tahrir deployed in [production](https://badges.fedoraproject.org/), or in
the [staging instance](https://badges.stg.fedoraproject.org/).

![PyPI](https://img.shields.io/pypi/v/tahrir.svg)
![Supported Python versions](https://img.shields.io/pypi/pyversions/tahrir.svg)
![Build status](https://github.com/fedora-infra/tahrir/actions/workflows/main.yml/badge.svg?branch=develop)
![Documentation](https://readthedocs.org/projects/tahrir/badge/?version=latest)
